@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.5.2
+-- @release v3.5.5
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -950,6 +950,8 @@ end
 capi.client.add_signal("property::floating_geometry")
 capi.client.add_signal("property::floating")
 capi.client.add_signal("property::dockable")
+capi.client.add_signal("marked")
+capi.client.add_signal("unmarked")
 
 capi.client.connect_signal("focus", client.focus.history.add)
 capi.client.connect_signal("unmanage", client.focus.history.delete)
