@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.5.2
+-- @release v3.5.5
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -56,8 +56,8 @@ function tag.move(new_index, target_tag)
     table.insert(tmp_tags, new_index, target_tag)
 
     for i, tmp_tag in ipairs(tmp_tags) do
-        tag.setproperty(tmp_tag, "index", i)
         tag.setscreen(tmp_tag, scr)
+        tag.setproperty(tmp_tag, "index", i)
     end
 end
 
@@ -158,7 +158,7 @@ function tag.delete(target_tag, fallback_tag)
 
     -- If no tags are visible, try and view one.
     if tag.selected(target_scr) == nil and ntags > 0 then
-        tag.history.restore()
+        tag.history.restore(nil, 1)
         if tag.selected(target_scr) == nil then
             tag.gettags(target_scr)[1].selected = true
         end
@@ -270,7 +270,22 @@ end
 -- @param t tag object
 -- @param s Screen number
 function tag.setscreen(t, s)
+    local s = s or capi.mouse.screen
+    local old_screen = tag.getproperty(t, "screen")
+    if s == old_screen then return end
+
+    -- Keeping the old index make very little sense when changing screen
+    tag.setproperty(t, "index", nil)
+
+    -- Change the screen
     tag.setproperty(t, "screen", s)
+
+    -- Make sure the client's screen matches its tags
+    for k,c in ipairs(t:clients()) do
+        c.screen = s --Move all clients
+        c:tags({t})
+    end
+    tag.history.restore(old_screen,1)
 end
 
 --- Get a tag's screen
@@ -530,7 +545,12 @@ function tag.withcurrent(c)
     if #tags == 0 then
         tags = tag.selectedlist(c.screen)
     end
-    c:tags(tags)
+    if #tags == 0 then
+        tags = tag.gettags(c.screen)
+    end
+    if #tags ~= 0 then
+        c:tags(tags)
+    end
 end
 
 local function attached_connect_signal_screen(screen, sig, func)
@@ -571,6 +591,7 @@ capi.client.connect_signal("manage", function(c, startup)
 end)
 
 capi.client.connect_signal("manage", tag.withcurrent)
+capi.tag.connect_signal("request::select", tag.viewonly)
 
 capi.tag.add_signal("property::hide")
 capi.tag.add_signal("property::icon")
