@@ -1,7 +1,7 @@
 -------------------------------------------------------------------------
 -- @author Sébastien Gross &lt;seb•ɱɩɲʋʃ•awesome•ɑƬ•chezwam•ɖɵʈ•org&gt
 -- @copyright 2009 Sébastien Gross
--- @release v3.5.2
+-- @release v3.5.5
 -------------------------------------------------------------------------
 
 local mouse = mouse
@@ -11,6 +11,7 @@ local wibox = require("wibox")
 local a_placement = require("awful.placement")
 local beautiful = require("beautiful")
 local textbox = require("wibox.widget.textbox")
+local background = require("wibox.widget.background")
 local setmetatable = setmetatable
 local ipairs = ipairs
 
@@ -78,7 +79,7 @@ end
 local function set_geometry(self)
     local my_geo = self.wibox:geometry()
     -- calculate width / height
-    local n_w, n_h = self.widget:fit(-1, -1)
+    local n_w, n_h = self.textbox:fit(-1, -1)
     if my_geo.width ~= n_w or my_geo.height ~= n_h then
         self.wibox:geometry({ width = n_w, height = n_h })
     end
@@ -119,9 +120,15 @@ end
 -- @param self The tooltip object.
 -- @param text New tooltip text.
 local function set_text(self, text)
-    self.widget:set_font(data[self].font)
-    self.widget:set_markup('<span color="' .. data[self].fg
-        .. '">' .. text .. "</span>")
+    self.textbox:set_text(text)
+    set_geometry(self)
+end
+
+--- Change displayed text.
+-- @param self The tooltip object.
+-- @param text New tooltip text, including pango markup.
+local function set_markup(self, text)
+    self.textbox:set_markup(text)
     set_geometry(self)
 end
 
@@ -134,17 +141,6 @@ local function set_timeout(self, timeout)
     end
 end
 
--- Load Default values.
--- @param self A tooltip object.
-local function set_defaults(self)
-    self.wibox.border_width = beautiful.tooltip_border_width or beautiful.border_width or 1
-    self.wibox.border_color = beautiful.tooltip_border_color or beautiful.border_normal or "#ffcb60"
-    self.wibox.opacity = beautiful.tooltip_opacity or 1
-    self.wibox:set_bg(beautiful.tooltip_bg_color or beautiful.bg_focus or "#ffcb60")
-    data[self].fg = beautiful.tooltip_fg_color or beautiful.fg_focus or "#000000"
-    data[self].font = beautiful.tooltip_font or beautiful.font or "terminus 6"
-end
-
 --- Add tooltip to an object.
 -- @param self The tooltip.
 -- @param object An object.
@@ -172,14 +168,13 @@ end
 -- @see add_to_object
 -- @see set_timeout
 -- @see set_text
+-- @see set_markup
 local function new(args)
     local self = {
         wibox =  wibox({ }),
         visible = false,
     }
 
-    local my_textbox = textbox()
-
     -- private data
     data[self] = {
         show = function() show(self) end,
@@ -188,27 +183,37 @@ local function new(args)
 
     -- export functions
     self.set_text = set_text
+    self.set_markup = set_markup
     self.set_timeout = set_timeout
     self.add_to_object = add_to_object
     self.remove_from_object = remove_from_object
 
-    set_defaults(self)
-
     -- setup the timer action only if needed
     if args.timer_function then
         data[self].timer = timer { timeout = args.timeout and args.timeout or 1 }
         data[self].timer_function = function()
-                self:set_text(args.timer_function())
+                self:set_markup(args.timer_function())
             end
         data[self].timer:connect_signal("timeout", data[self].timer_function)
     end
 
+    -- Set default properties
+    self.wibox.border_width = beautiful.tooltip_border_width or beautiful.border_width or 1
+    self.wibox.border_color = beautiful.tooltip_border_color or beautiful.border_normal or "#ffcb60"
+    self.wibox.opacity = beautiful.tooltip_opacity or 1
+    self.wibox:set_bg(beautiful.tooltip_bg_color or beautiful.bg_focus or "#ffcb60")
+    local fg = beautiful.tooltip_fg_color or beautiful.fg_focus or "#000000"
+    local font = beautiful.tooltip_font or beautiful.font or "terminus 6"
+
     -- set tooltip properties
     self.wibox.visible = false
     -- Who wants a non ontop tooltip ?
     self.wibox.ontop = true
-    self.wibox:set_widget(my_textbox)
-    self.widget = my_textbox
+    self.textbox = textbox()
+    self.textbox:set_font(font)
+    self.background = background(self.textbox)
+    self.background:set_fg(fg)
+    self.wibox:set_widget(self.background)
 
     -- add some signals on both the tooltip and widget
     self.wibox:connect_signal("mouse::enter", data[self].hide)
