@@ -1,7 +1,7 @@
 ----------------------------------------------------------------------------
 -- @author koniu &lt;gkusnierz@gmail.com&gt;
 -- @copyright 2008 koniu
--- @release v3.5.2
+-- @release v3.5.5
 ----------------------------------------------------------------------------
 
 -- Package environment
@@ -409,7 +409,7 @@ function naughty.notify(args)
         end
 
         -- is the icon file readable?
-        local success, res = pcall(function() return surface.load(icon) end)
+        local success, res = pcall(function() return surface.load_uncached(icon) end)
         if success then
             icon = res
         else
